@@ -21,6 +21,9 @@
 # define CONFIG_BFIN_SCRATCH_REG retn
 #endif
 
+/* U-Boot wants this config name */
+#define CONFIG_SYS_CACHELINE_SIZE L1_CACHE_BYTES
+
 /* Make sure the structure is properly aligned */
 #if ((CONFIG_SYS_GBL_DATA_ADDR & -4) != CONFIG_SYS_GBL_DATA_ADDR)
 # error CONFIG_SYS_GBL_DATA_ADDR: must be 4 byte aligned
@@ -106,14 +109,8 @@
 #ifndef CONFIG_SYS_MALLOC_BASE
 # define CONFIG_SYS_MALLOC_BASE (CONFIG_SYS_MONITOR_BASE - CONFIG_SYS_MALLOC_LEN)
 #endif
-#ifndef CONFIG_SYS_GBL_DATA_ADDR
-# define CONFIG_SYS_GBL_DATA_ADDR (CONFIG_SYS_MALLOC_BASE - GENERATED_GBL_DATA_SIZE)
-#endif
-#ifndef CONFIG_SYS_BD_INFO_ADDR
-# define CONFIG_SYS_BD_INFO_ADDR (CONFIG_SYS_GBL_DATA_ADDR - GENERATED_BD_INFO_SIZE)
-#endif
 #ifndef CONFIG_STACKBASE
-# define CONFIG_STACKBASE (CONFIG_SYS_BD_INFO_ADDR - 4)
+# define CONFIG_STACKBASE (CONFIG_SYS_MALLOC_BASE - 4)
 #endif
 #ifndef CONFIG_SYS_MEMTEST_START
 # define CONFIG_SYS_MEMTEST_START 0
@@ -165,8 +162,23 @@
 # undef CONFIG_SYS_HZ
 #endif
 #define CONFIG_SYS_HZ 1000
-#ifndef CONFIG_SYS_BAUDRATE_TABLE
-# define CONFIG_SYS_BAUDRATE_TABLE { 9600, 19200, 38400, 57600, 115200 }
+
+/* Blackfin POST tests */
+#ifdef CONFIG_POST_BSPEC1_GPIO_LEDS
+# define CONFIG_POST_BSPEC1 \
+	{ \
+		"LED test", "led", "This test verifies LEDs on the board.", \
+		POST_MEM | POST_ALWAYS, &led_post_test, NULL, NULL, \
+		CONFIG_SYS_POST_BSPEC1, \
+	}
+#endif
+#ifdef CONFIG_POST_BSPEC2_GPIO_BUTTONS
+# define CONFIG_POST_BSPEC2 \
+	{ \
+		"Button test", "button", "This test verifies buttons on the board.", \
+		POST_MEM | POST_ALWAYS, &button_post_test, NULL, NULL, \
+		CONFIG_SYS_POST_BSPEC2, \
+	}
 #endif
 
 #endif
